@@ -6,7 +6,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.31';
+our $VERSION = '1.32';
 
 my %TAG_TEMPLATE;
 $TAG_TEMPLATE{css} = [qw(link rel stylesheet href)];
@@ -26,7 +26,7 @@ has store => sub {
   my $self = shift;
   Mojolicious::Plugin::AssetPack::Store->new(
     classes => [@{$self->_app->static->classes}],
-    paths   => [$self->_app->home->rel_dir('assets')],
+    paths   => [$self->_app->home->rel_file('assets')],
     ua      => $self->ua,
   );
 };
@@ -130,7 +130,6 @@ sub _correct_mode {
 
 sub _pipes {
   my ($self, $names) = @_;
-  unshift @$names, 'Reloader' if $ENV{MOJO_ASSETPACK_RELOADER};    # experimental
 
   $self->{pipes} = [
     map {
@@ -279,7 +278,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.31
+1.32
 
 =head1 SYNOPSIS
 
@@ -366,7 +365,7 @@ set it to a value between 0 and 3, where 3 provides the most debug.
 =item * MOJO_ASSETPACK_LAZY
 
 Set this environment variable if you want to delay processing the assets until
-they are requested. This can be very useful while developing, and the assets
+they are requested. This can be very useful while developing when the assets
 are changed frequently.
 
 =back
